import InterfaceBuilderKit
from PyObjCTools.TestSupport import TestCase


class TestIBGeometry(TestCase):
    def testConstants(self):
        self.assertEqual(InterfaceBuilderKit.IBNoDirection, 0)
        self.assertEqual(InterfaceBuilderKit.IBMinXDirection, 1)
        self.assertEqual(InterfaceBuilderKit.IBMaxXDirection, 2)
        self.assertEqual(InterfaceBuilderKit.IBMinYDirection, 4)
        self.assertEqual(InterfaceBuilderKit.IBMaxYDirection, 8)
        self.assertEqual(
            InterfaceBuilderKit.IBMinXMinYDirection,
            (InterfaceBuilderKit.IBMinXDirection | InterfaceBuilderKit.IBMinYDirection),
        )
        self.assertEqual(
            InterfaceBuilderKit.IBMinXMaxYDirection,
            (InterfaceBuilderKit.IBMinXDirection | InterfaceBuilderKit.IBMaxYDirection),
        )
        self.assertEqual(
            InterfaceBuilderKit.IBMaxXMinYDirection,
            (InterfaceBuilderKit.IBMaxXDirection | InterfaceBuilderKit.IBMinYDirection),
        )
        self.assertEqual(
            InterfaceBuilderKit.IBMaxXMaxYDirection,
            (InterfaceBuilderKit.IBMaxXDirection | InterfaceBuilderKit.IBMaxYDirection),
        )

    def testStructs(self):
        o = InterfaceBuilderKit.IBInset()
        self.assertHasAttr(o, "left")
        self.assertHasAttr(o, "top")
        self.assertHasAttr(o, "right")
        self.assertHasAttr(o, "bottom")
        self.assertIsInstance(o.left, float)
        self.assertIsInstance(o.top, float)
        self.assertIsInstance(o.right, float)
        self.assertIsInstance(o.bottom, float)



# Generated file, don't edit
# Source: BridgeSupport/InterfaceBuilderKit.bridgesupport
# Last update: Thu Jul 21 08:47:20 2011
#
# flake8: noqa

import sys

import objc

if sys.maxsize > 2 ** 32:

    def sel32or64(a, b):
        return b


else:

    def sel32or64(a, b):
        return a


if sys.byteorder == "little":

    def littleOrBig(a, b):
        return a


else:

    def littleOrBig(a, b):
        return b


misc = {
    "IBDocumentStorage*": objc.createOpaquePointerType(
        "IBDocumentStorage*", b"^{IBDocumentStorage=}"
    ),
    "IBInset": objc.createStructType(
        "IBInset", b'{IBInsetTag="left"f"top"f"right"f"bottom"f}', None
    ),
}
constants = """$IBAdditionalLocalizableKeyPaths$IBAttributeKeyPaths$IBLocalizableGeometryKeyPaths$IBLocalizableStringKeyPaths$IBToManyRelationshipKeyPaths$IBToOneRelationshipKeyPaths$"""
enums = """$IBMaxXDirection@2$IBMaxXMaxYDirection@10$IBMaxXMinYDirection@6$IBMaxYDirection@8$IBMinXDirection@1$IBMinXMaxYDirection@9$IBMinXMinYDirection@5$IBMinYDirection@4$IBNoDirection@0$"""
misc.update({})
functions = {}
cftypes = []
r = objc.registerMetaDataForSelector
objc._updatingMetadata(True)
try:
    pass
    r(
        b"IBDocument",
        b"addObject:toParent:",
        {"retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}}},
    )
    r(
        b"IBDocument",
        b"childrenOfObject:",
        {"retval": {"type": b"@"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"IBDocument",
        b"connectAction:ofSourceObject:toDestinationObject:",
        {
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"IBDocument",
        b"connectBinding:ofSourceObject:toDestinationObject:keyPath:options:",
        {
            "retval": {"type": b"v"},
            "arguments": {
                2: {"type": b"@"},
                3: {"type": b"@"},
                4: {"type": b"@"},
                5: {"type": b"@"},
                6: {"type": b"@"},
            },
        },
    )
    r(
        b"IBDocument",
        b"connectOutlet:ofSourceObject:toDestinationObject:",
        {
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"IBDocument",
        b"documentForObject:",
        {"retval": {"type": b"@"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"IBDocument",
        b"documentImageNamed:",
        {"retval": {"type": b"@"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"IBDocument",
        b"metadataForKey:ofObject:",
        {"retval": {"type": b"@"}, "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}}},
    )
    r(
        b"IBDocument",
        b"moveObject:toParent:",
        {"retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}}},
    )
    r(b"IBDocument", b"objects", {"retval": {"type": b"@"}})
    r(
        b"IBDocument",
        b"parentOfObject:",
        {"retval": {"type": b"@"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"IBDocument",
        b"removeObject:",
        {"retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"IBDocument",
        b"setMetadata:forKey:ofObject:",
        {
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(b"IBDocument", b"topLevelObjects", {"retval": {"type": b"@"}})
    r(b"IBInspector", b"document", {"retval": {"type": b"@"}})
    r(b"IBInspector", b"inspectedObjects", {"retval": {"type": b"@"}})
    r(b"IBInspector", b"inspectedObjectsController", {"retval": {"type": b"@"}})
    r(b"IBInspector", b"label", {"retval": {"type": b"@"}})
    r(b"IBInspector", b"refresh", {"retval": {"type": b"v"}})
    r(b"IBInspector", b"sharedInstance", {"retval": {"type": b"@"}})
    r(b"IBInspector", b"supportsMultipleObjectInspection", {"retval": {"type": b"Z"}})
    r(b"IBInspector", b"view", {"retval": {"type": b"@"}})
    r(b"IBInspector", b"viewNibName", {"retval": {"type": b"@"}})
    r(b"IBPlugin", b"didLoad", {"retval": {"type": b"v"}})
    r(
        b"IBPlugin",
        b"document:didAddDraggedObjects:fromDraggedLibraryView:",
        {
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(b"IBPlugin", b"label", {"retval": {"type": b"@"}})
    r(b"IBPlugin", b"libraryNibNames", {"retval": {"type": b"@"}})
    r(
        b"IBPlugin",
        b"pasteboardObjectsForDraggedLibraryView:",
        {"retval": {"type": b"@"}, "arguments": {2: {"type": b"@"}}},
    )
    r(b"IBPlugin", b"preferencesView", {"retval": {"type": b"@"}})
    r(b"IBPlugin", b"requiredFrameworks", {"retval": {"type": b"@"}})
    r(b"IBPlugin", b"sharedInstance", {"retval": {"type": b"@"}})
    r(b"IBPlugin", b"willUnload", {"retval": {"type": b"v"}})
    r(
        b"NSObject",
        b"ibAwakeInDesignableDocument:",
        {"retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(b"NSObject", b"ibDefaultChildren", {"retval": {"type": b"@"}})
    r(b"NSObject", b"ibDefaultImage", {"retval": {"type": b"@"}})
    r(b"NSObject", b"ibDefaultLabel", {"retval": {"type": b"@"}})
    r(
        b"NSObject",
        b"ibDidAddToDesignableDocument:",
        {"retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"ibDidRemoveFromDesignableDocument:",
        {"retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"ibIsChildInitiallySelectable:",
        {"retval": {"type": b"Z"}, "arguments": {2: {"type": b"@"}}},
    )
    r(b"NSObject", b"ibRemoveChildren:", {"retval": {"type": b"Z"}})
    r(
        b"NSObject",
        b"ibIsChildViewUserMovable:",
        {"retval": {"type": b"Z"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"ibIsChildViewUserSizable:",
        {"retval": {"type": b"Z"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"ibObjectAtLocation:inWindowController:",
        {
            "retval": {"type": b"@"},
            "arguments": {
                2: {"type": sel32or64(b"{_NSPoint=ff}", b"{CGPoint=dd}")},
                3: {"type": b"@"},
            },
        },
    )
    r(
        b"NSObject",
        b"ibPopulateAttributeInspectorClasses:",
        {"retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"ibPopulateKeyPaths:",
        {"retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"ibRectForChild:inWindowController:",
        {
            "retval": {
                "type": sel32or64(
                    b"{_NSRect={_NSPoint=ff}{_NSSize=ff}}",
                    b"{CGRect={CGPoint=dd}{CGSize=dd}}",
                )
            },
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSView",
        b"ibBaselineAtIndex:",
        {"retval": {"type": b"f"}, "arguments": {2: {"type": b"i"}}},
    )
    r(b"NSView", b"ibBaselineCount", {"retval": {"type": b"i"}})
    r(b"NSView", b"ibDesignableContentView", {"retval": {"type": b"@"}})
    r(b"NSView", b"ibLayoutInset", {"retval": {"type": b"{IBInsetTag=ffff}"}})
    r(
        b"NSView",
        b"ibMaximumSize",
        {"retval": {"type": sel32or64(b"{_NSSize=ff}", b"{CGSize=dd}")}},
    )
    r(
        b"NSView",
        b"ibMinimumSize",
        {"retval": {"type": sel32or64(b"{_NSSize=ff}", b"{CGSize=dd}")}},
    )
    r(
        b"NSView",
        b"ibPreferredDesignSize",
        {"retval": {"type": sel32or64(b"{_NSSize=ff}", b"{CGSize=dd}")}},
    )
    r(b"NSView", b"ibPreferredResizeDirection", {"retval": {"type": b"i"}})
finally:
    objc._updatingMetadata(False)
protocols = {
    "IBObjectIntegration": objc.informal_protocol(
        "IBObjectIntegration",
        [
            objc.selector(
                None, b"ibAwakeInDesignableDocument:", b"v@:@", isRequired=False
            ),
            objc.selector(None, b"ibDefaultChildren", b"@@:", isRequired=False),
            objc.selector(None, b"ibDefaultImage", b"@@:", isRequired=False),
            objc.selector(None, b"ibDefaultLabel", b"@@:", isRequired=False),
            objc.selector(None, b"ibRemoveChildren:", b"Z@:@", isRequired=False),
            objc.selector(
                None, b"ibDidAddToDesignableDocument:", b"v@:@", isRequired=False
            ),
            objc.selector(
                None, b"ibDidRemoveFromDesignableDocument:", b"v@:@", isRequired=False
            ),
            objc.selector(
                None, b"ibIsChildInitiallySelectable:", b"Z@:@", isRequired=False
            ),
            objc.selector(
                None, b"ibIsChildViewUserMovable:", b"Z@:@", isRequired=False
            ),
            objc.selector(
                None, b"ibIsChildViewUserSizable:", b"Z@:@", isRequired=False
            ),
            objc.selector(
                None,
                b"ibObjectAtLocation:inWindowController:",
                sel32or64(b"@@:{_NSPoint=ff}@", b"@@:{CGPoint=dd}@"),
                isRequired=False,
            ),
            objc.selector(
                None, b"ibPopulateAttributeInspectorClasses:", b"v@:@", isRequired=False
            ),
            objc.selector(None, b"ibPopulateKeyPaths:", b"v@:@", isRequired=False),
            objc.selector(
                None,
                b"ibRectForChild:inWindowController:",
                sel32or64(
                    b"{_NSRect={_NSPoint=ff}{_NSSize=ff}}@:@@",
                    b"{CGRect={CGPoint=dd}{CGSize=dd}}@:@@",
                ),
                isRequired=False,
            ),
        ],
    )
}



""" Unittests """
import os

if (
    "DYLD_FRAMEWORK_PATH" not in os.environ
    or "Library/PrivateFrameworks/" not in os.environ["DYLD_FRAMEWORK_PATH"]
):
    # Check for:
    # DYLD_FRAMEWORK_PATH='/Developer/Library/PrivateFrameworks/'

    raise ImportError(
        "Please define DYLD_FRAMEWORK_PATH, otherwise the tests will fail"
    )



import InterfaceBuilderKit
from PyObjCTools.TestSupport import TestCase


class TestIBObjectIntegrationHelper(InterfaceBuilderKit.NSObject):
    def ibIsChildViewUserMovable_(self, v):
        return False

    def ibIsChildViewUserSizable_(self, v):
        return False

    def ibRemoveChildren_(self, v):
        return True


class TestIBObjectIntegration(TestCase):
    def testContants(self):
        self.assertIsInstance(InterfaceBuilderKit.IBAttributeKeyPaths, str)
        self.assertIsInstance(InterfaceBuilderKit.IBToOneRelationshipKeyPaths, str)
        self.assertIsInstance(InterfaceBuilderKit.IBToManyRelationshipKeyPaths, str)
        self.assertIsInstance(InterfaceBuilderKit.IBLocalizableStringKeyPaths, str)
        self.assertIsInstance(InterfaceBuilderKit.IBLocalizableGeometryKeyPaths, str)
        self.assertIsInstance(InterfaceBuilderKit.IBAdditionalLocalizableKeyPaths, str)

    def testMethods(self):
        self.assertResultIsBOOL(TestIBObjectIntegrationHelper.ibIsChildViewUserMovable_)
        self.assertResultIsBOOL(TestIBObjectIntegrationHelper.ibIsChildViewUserSizable_)
        self.assertResultIsBOOL(TestIBObjectIntegrationHelper.ibRemoveChildren_)



"""
Wrappers for the framework "InterfaceBuilderKit" on macOS. This framework
is only available when you've installed Xcode 3.x, but not with earlier or
later releases of Xcode.

The Interface Builder Kit is a framework containing the classes you use to
implement custom plug-ins for Interface Builder. A plug-in injects one or
more custom objects into Interface Builder's library window. From the library
window, users can access your custom objects and drag them into their nib
files just as they would the standard system controls. You can also use this
framework to implement inspectors for manipulating your objects at runtime.

These wrappers don't include documentation, please check Apple's documention
for information on how to use this framework and PyObjC's documentation
for general tips and tricks regarding the translation between Python
and (Objective-)C frameworks

NOTE: To run the unittests for this framework use::

    $ env DYLD_FRAMEWORK_PATH="$(xcode-select -print-path)/Library/PrivateFrameworks/" python setup.py test  # noqa: B950

This is needed because the InterfaceBuilderKit framework won't load otherwise.
"""
from pyobjc_setup import setup

VERSION = '7.2'

setup(
    name="pyobjc-framework-InterfaceBuilderKit",
    description="Wrappers for the framework InterfaceBuilderKit on macOS",
    min_os_level="10.5",
    max_os_level="10.6",
    packages=["InterfaceBuilderKit"],
    version=VERSION,
    install_requires=["pyobjc-core>=" + VERSION, "pyobjc-framework-Cocoa>=" + VERSION],
    long_description=__doc__,
)



import InterfaceBuilderKit
from PyObjCTools.TestSupport import TestCase


class TestIBInspector(TestCase):
    def testMethods(self):
        self.assertResultIsBOOL(
            InterfaceBuilderKit.IBInspector.supportsMultipleObjectInspection
        )



"""
Some simple tests to check that the framework is properly wrapped.
"""
import InterfaceBuilderKit
from PyObjCTools.TestSupport import TestCase
import objc


class TestInterfaceBuilderKit(TestCase):
    def testClasses(self):
        self.assertHasAttr(InterfaceBuilderKit, "IBDocument")
        self.assertIsInstance(InterfaceBuilderKit.IBDocument, objc.objc_class)
        self.assertHasAttr(InterfaceBuilderKit, "IBPlugin")
        self.assertIsInstance(InterfaceBuilderKit.IBPlugin, objc.objc_class)
